#!/usr/bin/env python
# -*- coding: utf-8 -*-
import sys, os
from setuptools import setup

icons = []
for dirpath, dirnames, filenames in os.walk("data/icons/"):
    relpath = dirpath[len("data/icons/"):]
    if relpath and filenames:
        icons.append((sys.prefix+"/share/icons/hicolor/"+relpath, [os.path.join(dirpath, x) for x in filenames]))

common = []
for dirpath, dirnames, filenames in os.walk("data/common/"):
    relpath = dirpath[len("data/common/"):]
    if relpath and filenames:
        common.append((sys.prefix+"/share/zorin-appearance/"+relpath, [os.path.join(dirpath, x) for x in filenames]))


setup(
    name='zorin-appearance',
    version='5.3',

    url='http://zorin.com',

    author='Zorin OS Technologies Ltd.',
    author_email='os@zoringroup.com',

    packages=['zorin_appearance'],
    package_dir={'zorin_appearance': 'zorin_appearance'},

    data_files=[
        (sys.prefix+'/share/applications',['zorin-appearance.desktop']),
        (sys.prefix+'/share/pixmaps', ['zorin-appearance.png']),
        (sys.prefix+'/share/glib-2.0/schemas', ['schemas/com.zorin.desktop.appearance.gschema.xml'])
    ] + icons + common,

    zip_safe=True,
    include_package_data=True,

    platforms='any',

    install_requires=[
        'PyGObject',
        'setuptools'
    ],

    description='Zorin Appearance',
    long_description=("Modify the look and feel of your Zorin OS desktop."),

    keywords=['appearance', 'desktop', 'panel', 'theme', 'extension', 'settings', 'tweak'],

    license='GPL-2.0',
    classifiers=[
        'Programming Language :: Python',
        'Environment :: X11 Applications :: GTK',
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: End Users/Desktop',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Operating System :: POSIX :: Linux',
        'Topic :: Desktop Environment'
    ],

    entry_points={
        'gui_scripts': [
            'zorin-appearance = zorin_appearance.__main__:main',
        ]
    },
)
